NaMaster: nmt_binning_scheme_flat Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_binning_scheme_flat Struct Reference

Flat-sky bandpowers. More...

`#include <namaster.h>`

## Data Fields
int | n_bands
| Number of bandpowers stored. More...
flouble * | ell_0_list
| Lower edge of each bandpower. More...
flouble * | ell_f_list
| Upper edge of each bandpower. More...

## Detailed Description

Flat-sky bandpowers.

This structure defines bandpowers for flat-sky power spectra. These are currently defined only by band edges (assumed flat weights within band).

## Field Documentation

flouble* nmt_binning_scheme_flat::ell_0_list

Lower edge of each bandpower.

flouble* nmt_binning_scheme_flat::ell_f_list

Upper edge of each bandpower.

int nmt_binning_scheme_flat::n_bands

Number of bandpowers stored.

The documentation for this struct was generated from the following file:

- namaster.h